# User Guide

In this part, we will cover

1. How to create a project
1. How to build and deploy the documents
1. Various configuration options
1. Markdown and code examples

```toc
:maxdepth: 2

create
edit
build
deploy
markdown
code
code_tabs
slides
colab
```
